==> kui-web-terminal-container-v2.0.6-3.tar.gz: package/mdist/components/Content/Editor/RevertFileButton.js <==
/*
 * Copyright 2020 IBM Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { i18n } from '@kui-shell/core';
const strings = i18n('plugin-client-common', 'editor');
/**
 * Offer a Revert button
 *
 */
export default function RevertFileButton(editor, repl, response, onRevert) {
    return {
        mode: 'Revert',
        kind: 'view',
        label: strings('revert'),
        command: () => __awaiter(this, void 0, void 0, function* () {
            try {
                const stats = (yield repl.rexec(`fstat ${repl.encodeComponent(response.spec.fullpath)} --with-data --enoent-ok`)).content;
                onRevert(true, stats.data);
            }
            catch (err) {
                onRevert(false);
            }
        })
    };
}
//# sourceMappingURL=RevertFileButton.js.map

==> kui-web-terminal-container-v2.3.8-5.tar.gz: package/mdist/components/Content/Editor/RevertFileButton.js <==
/*
 * Copyright 2020 The Kubernetes Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import React from 'react';
import { i18n } from '@kui-shell/core';
import Icons from '../../spi/Icons';
const strings = i18n('plugin-client-common', 'editor');
/**
 * Offer a Revert button
 *
 */
export default function RevertFileButton(editor, repl, response, onRevert) {
    return {
        mode: 'Revert',
        kind: 'view',
        label: strings('revert'),
        icon: React.createElement(Icons, { icon: "Revert" }),
        command: () => __awaiter(this, void 0, void 0, function* () {
            try {
                const stats = (yield repl.rexec(`vfs fstat ${repl.encodeComponent(response.spec.fullpath)} --with-data --enoent-ok`)).content;
                onRevert(true, stats.data);
            }
            catch (err) {
                onRevert(false);
            }
        })
    };
}
//# sourceMappingURL=RevertFileButton.js.map
